##  Creating and Managing Tag Groups
Admins can create and manage tag groups and tags in the administration area under the section Tagging. When creating tag groups, you can limit them to particular fact sheet types if needed or make them available for all fact sheet types.
You can edit existing tags and also delete them. However, in order to delete a tag group, all the tags in that group must be deleted or removed from that tag group. Similarly, to delete a tag, all instances of that tag assigned to fact sheets must first be removed, including from archived fact sheets. For a detailed guide on creating, managing, and deleting tag groups and tags, see [Tagging](https://help.sap.com/docs/leanix/ea/tagging?locale=en-US&state=PRODUCTION&version=CLOUD "This guide covers the essential steps for managing tags, including creating tag groups, adding and editing tags within those groups, and deleting tags and tag groups. Suggest Edits Introduction").
